@@ -1,4 +1,4 @@
-from stdnet.exceptions import ImproperlyConfigured, BadCacheDataStructure
+from stdnet.exceptions import *
 
 novalue = object()
 
@@ -36,7 +36,7 @@ class BaseBackend(object):
     * *params* dictionary of configuration parameters
     * *pickler* calss for serializing and unserializing data. It must implement the *loads* and *dumps* methods.
     '''
-    def __init__(self, name, params, pickler = default_pickler):
+    def __init__(self, name, params, pickler = None):
         self.__name = name
         timeout = params.get('timeout', 0)
         try:
@@ -48,7 +48,7 @@ class BaseBackend(object):
         self._keys      = {}
         self.fields     = []
         self.params     = params
-        self.pickler    = pickler 
+        self.pickler    = pickler or default_pickler
 
     @property
     def name(self):
@@ -64,9 +64,20 @@ class BaseBackend(object):
         pass
     
     def get_object(self, meta, name, value):
+        '''Retrive an object from the database. If object is not available, it raise
+and :ref:`ObjectNotFund <utility-exceptions>` exception.
+
+    * *meta* :ref:`database metaclass <database-metaclass>` or model
+    * *name* name of field (must be unique)
+    * *value* value of field to search.'''
         if name != 'id':
-            value = self.get(meta.basekey(name,value))
-        return self.hash(meta.basekey()).get(value)
+            value = self._get(meta.basekey(name,value))
+        if value is None:
+            raise ObjectNotFund
+        value = self.hash(meta.basekey()).get(value)
+        if value is None:
+            raise ObjectNotFund
+        return value
     
     def add_object(self, obj, commit = True):
         '''Add a model object to the database:
@@ -74,7 +85,7 @@ class BaseBackend(object):
         * *obj* instance of :ref:`StdModel <model-model>` to add to database
         * *commit* If True, *obj* is saved to database, otherwise it remains in local cache.
         '''
-        meta   = obj.meta
+        meta   = obj._meta
         id     = meta.basekey()
         cache  = self._cachepipe
         cvalue = cache.get(id,None)
@@ -136,7 +147,7 @@ class BaseBackend(object):
             
     def delete_object(self, obj):
         '''Delete an object from the database'''
-        meta   = obj.meta
+        meta   = obj._meta
         id     = meta.basekey()
         hash   = self.hash(id)
         if not hash.delete(obj.id):
@@ -146,13 +157,17 @@ class BaseBackend(object):
     
     def delete_indexes(self, obj):
         pass
-            
-    def get(self, key, default=None):
-        """
-        Fetch a given key from the cache. If the key does not exist, return
-        default, which itself defaults to None.
-        """
-        raise NotImplementedError
+    
+    def set(self, id, value, timeout = None):
+        value = self.pickler.dumps(value)
+        return self._set(id,value,timeout)
+    
+    def get(self, id, default = None):
+        v = self._get(id)
+        if v:
+            return self.pickler.loads(v)
+        else:
+            return default
 
     def get_many(self, keys):
         """
@@ -219,6 +234,12 @@ class BaseBackend(object):
 
     # VIRTUAL METHODS
     
+    def _set(self, id, value, timeout):
+        raise NotImplementedError
+    
+    def _get(self, id):
+        raise NotImplementedError
+    
     def _set_keys(self):
         raise NotImplementedError
             
