@@ -1,6 +1,7 @@
 import copy
 from fields import Field, AutoField
 from stdnet.exceptions import *
+from query import UnregisteredManager 
 
 def get_fields(bases, attrs):
     fields = {}
@@ -17,21 +18,21 @@ def get_fields(bases, attrs):
 
 
 class Metaclass(object):
-    
-    def __init__(self, model, fields, abstract = False, keyprefix = None):
-        '''Model metaclass contains all the information which relates a python class to a database model. An instnace
-is initiated when registering a new model with a database backend:
+    '''A database model metaclass contains all the information which relates a python class to a database model.
+    An instance is initiated when registering a new model with a database backend:
 
-    * *model* a model class
+    * *model* a subclass of :ref:`StdModel <model-model>`
     * *fields* dictionary of field instances
-    * *abstract* if True, it represents an abstract model and no database model are created
-    * *keyprefix*
+    * *abstract* if True, it represents an abstract model and no database elements are created.
+    * *keyprefix* prefix for the database table (by default 'stdnet')
 '''
+    def __init__(self, model, fields, abstract = False, keyprefix = None):
         self.abstract  = abstract
         self.keyprefix = keyprefix
         self.model     = model
         self.name      = model.__name__.lower()
         self.fields    = fields
+        self.timeout   = 0
         self.related   = {}
         model._meta    = self
         if not abstract:
@@ -55,37 +56,51 @@ is initiated when registering a new model with a database backend:
         
     @property
     def pk(self):
+        '''primary key field'''
         return self.fields['id']
     
     @property
     def id(self):
-        return self.pk.value
+        '''primary key value'''
+        return self.pk.get_value()
     
     def has_pk(self):
-        return self.pk.value
+        return self.pk._value
         
     def basekey(self, *args):
+        '''Calculate the key to access model hash-table, and model filters in the database.
+        For example::
+        
+            >>> a = Author(name = 'Dante Alighieri').save()
+            >>> a.meta.basekey()
+            'stdnet:author'
+            '''
         key = '%s%s' % (self.keyprefix,self.name)
         for arg in args:
             key = '%s:%s' % (key,arg)
         return key
     
-    def save(self, commit = True):
-        res = self.pk.save(commit)
-        for name,field in self.fields.items():
-            if name is not 'id':
-                field.save(commit)
-        
-    def delete(self):
-        '''Delete the object from the back-end database and return the number of objects removed.'''
-        if not self.has_pk():
-            raise StdNetException('Cannot delete object. It was never saved.')
-        # Gather related objects to delete
-        objs = self.related_objects()
-        T = 0
-        for obj in objs:
-            T += obj.delete()
-        return T + self.cursor.delete_object(self)
+    @property
+    def uniqueid(self):
+        '''Unique id for an instance. This is unique across multiple model types.'''
+        return self.basekey(self.id)
+    
+    def table(self):
+        '''Return an instance of :ref:`HashTable <hash-structure>` holding
+        the model table'''
+        return self.cursor.hash(self.basekey())
+    
+    def isvalid(self):
+        validation_errors = {}
+        valid = True
+        for field in self.fields.itervalues():
+            try:
+                valid = valid & field.isvalid()
+            except FieldError, e:
+                valid = False
+                validation_errors[field.name] = str(e)
+        self.validation_errors = validation_errors 
+        return valid
     
     def related_objects(self):
         objs = []
@@ -102,7 +117,6 @@ is initiated when registering a new model with a database backend:
         return obj
 
 
-
 class DataMetaClass(type):
     '''StdModel python metaclass'''
     def __new__(cls, name, bases, attrs):
@@ -122,6 +136,9 @@ class DataMetaClass(type):
         else:
             kwargs   = {}
         Metaclass(new_class,fields,**kwargs)
+        objects = getattr(new_class,'objects',None)
+        if objects is None:
+            new_class.objects = UnregisteredManager(new_class)
         return new_class
     
 
